
CHANGES
=======

0.3 (2014-03-14)
----------------

Key length is automatically determined when it is not given.
Remove filter function.
Slightly decreasing amount of memory usage.

0.2 (2013-10-12)
----------------

Simplify the step of creating new sketch.

0.1 (2013-10-11)
----------------

Initial release.

